@@ -1,4 +1,4 @@
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 
 from tzlocal import get_localzone
 
@@ -16,8 +16,11 @@ from apscheduler.util import (
     convert_to_datetime,
     datetime_ceil,
     datetime_repr,
+    datetime_utc_add,
 )
 
+UTC = timezone.utc
+
 
 class CronTrigger(BaseTrigger):
     """
@@ -62,7 +65,7 @@ class CronTrigger(BaseTrigger):
         "second": BaseField,
     }
 
-    __slots__ = "timezone", "start_date", "end_date", "fields", "jitter"
+    __slots__ = "end_date", "fields", "jitter", "start_date", "timezone"
 
     def __init__(
         self,
@@ -183,9 +186,7 @@ class CronTrigger(BaseTrigger):
                     i += 1
 
         difference = datetime(**values) - dateval.replace(tzinfo=None)
-        dateval = datetime.fromtimestamp(
-            dateval.timestamp() + difference.total_seconds(), self.timezone
-        )
+        dateval = datetime_utc_add(dateval, difference)
         return dateval, fieldnum
 
     def _set_field_value(self, dateval, fieldnum, new_value):
@@ -202,19 +203,23 @@ class CronTrigger(BaseTrigger):
         return datetime(**values, tzinfo=self.timezone, fold=dateval.fold)
 
     def get_next_fire_time(self, previous_fire_time, now):
-        # If datetime is folded, cast in ISO format to ensure they advance correctly
-        if previous_fire_time and previous_fire_time.fold == 1:
-            previous_fire_time = datetime.fromisoformat(previous_fire_time.isoformat())
-
-        if now.fold == 1:
-            now = datetime.fromisoformat(now.isoformat()) + timedelta(microseconds=1)
-
         if previous_fire_time:
-            start_date = min(now, previous_fire_time + timedelta(microseconds=1))
+            start_date = min(
+                now.astimezone(UTC),
+                datetime_utc_add(
+                    previous_fire_time, timedelta(microseconds=1)
+                ).astimezone(UTC),
+            ).astimezone(self.timezone)
             if start_date == previous_fire_time:
-                start_date += timedelta(microseconds=1)
+                start_date = datetime_utc_add(start_date, timedelta(microseconds=1))
         else:
-            start_date = max(now, self.start_date) if self.start_date else now
+            start_date = (
+                max(now.astimezone(UTC), self.start_date.astimezone(UTC)).astimezone(
+                    self.timezone
+                )
+                if self.start_date
+                else now
+            )
 
         fieldnum = 0
         next_date = datetime_ceil(start_date).astimezone(self.timezone)
